<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer opponent for Blokus</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All with number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DocbookReader</name>
    <message>
        <source>Previous</source>
        <extracomment>Go to previous page of user manual</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents</source>
        <extracomment>Go to table of contents of user manual</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <extracomment>Go to next page of user manual</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled.png</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Junior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Players:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press back again to exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Image…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Very good</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Good</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PentobiToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Junior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled.blksgf</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use layout optimized for desktop.</source>
        <extracomment>Description for command line option --desktop</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--mobile and --desktop cannot be used both</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
